==> granule_1.2.0.orig.tar.gz: granule-1.2.0.orig/src/DeckView.h <==
// -*- c++ -*-
//------------------------------------------------------------------------------
// $Id: DeckView.h,v 1.18 2005/11/21 00:25:17 vlg Exp $
//------------------------------------------------------------------------------
//                            DeckView.h
//------------------------------------------------------------------------------
//  Copyright (c) 2004 by Vladislav Grinchenko 
//
//  This program is free software; you can redistribute it and/or 
//  modify it under the terms of the GNU General Public License   
//  as published by the Free Software Foundation; either version  
//  2 of the License, or (at your option) any later version.      
//------------------------------------------------------------------------------
//
// Date   : Fri Feb  6 23:37:11 EST 2004
//
//------------------------------------------------------------------------------
#ifndef DECK_VIEWER_H
#define DECK_VIEWER_H

#ifdef HAVE_CONFIG_H
#    include "config.h"
#endif

#include <gtkmm/messagedialog.h>
#include <gtkmm/entry.h>
#include <gtkmm/label.h>
#include <gtkmm/frame.h>
#include <gtkmm/button.h>
#include <gtkmm/box.h>
#include <gtkmm/treeview.h>
#include <gtkmm/liststore.h>
#include <gtkmm/scrolledwindow.h>

class VDeck;

class DeckView : public Gtk::Dialog
{
public:
	DeckView (VDeck& deck_, int selected_row_);
	~DeckView ();

	/** Has the Deck been modified so that it might invalidate
		the iterators? Deleting a card and moving card(s) up/down
		might invalidated external iterators. 
		Editing/Saving, however, does not.
	*/
	bool is_modified () const { return m_modified; }

	/** User selected a row in the cards view
	 */
	void on_card_selected ();

	/** Called in response to pressing <Close> button
	 */
	void on_close_clicked () { /* no-op */ }

	/** Called when the user clicks on the column header to 
		sort the list of words.
	 */
	void on_column_sorted ();

	/** Sort Front column
	 */
	int on_sort_compare_front (const Gtk::TreeModel::iterator& a_, 
							   const Gtk::TreeModel::iterator& b_)
	{
		return (sort_compare_impl (a_, b_, 0));
	}

	/** Sort Back column
	 */
	int on_sort_compare_back (const Gtk::TreeModel::iterator& a_, 
							  const Gtk::TreeModel::iterator& b_)
	{
		return (sort_compare_impl (a_, b_, 1));
	}

	// -*- Sidebar action button callbacks -*-
	void on_add_clicked         ();
	void on_edit_clicked        ();
	void on_delete_clicked      ();
	void on_more_clicked        ();
	void on_card_up_clicked     ();
	void on_card_down_clicked   ();
	void on_add_card_to_cardbox ();

	void add_new_card (Card* card_);

private:
	/** Column sorting implementation
	 */
	int sort_compare_impl (const Gtk::TreeModel::iterator& a_, 
						   const Gtk::TreeModel::iterator& b_,
						   int column_);

	void set_cards_count ();
	void set_win_name ();

	static Glib::ustring trim_multiline (const Glib::ustring& text_);

private:
	typedef Gtk::TreeModel::Children children_t;
	typedef children_t::iterator chiter_t;

	struct ModelColumns : public Gtk::TreeModelColumnRecord
	{
		Gtk::TreeModelColumn<Glib::ustring> m_front_row;
		Gtk::TreeModelColumn<Glib::ustring> m_back_row;
		Gtk::TreeModelColumn<VCard*>        m_card;    // Hidden Card reference.
		
		ModelColumns () 
			{ 
				add (m_front_row); add (m_back_row); add (m_card); 
			}
	};

	void autoscroll_up ();
	void autoscroll_down ();


	const ModelColumns   m_columns;
	Gtk::TreeView        m_tree_view;
	Gtk::ScrolledWindow* m_scrollwin;

	/// TreeModel
	Glib::RefPtr<Gtk::ListStore> m_list_store_ref; 

    /// Selection in current TreeView
	Glib::RefPtr<Gtk::TreeSelection> m_tree_sel_ref; 

	/** De-activate action buttons depending on the type 
	    of the underlying VDeck object.
	*/
	void set_sensitivity ();

private:
	Gtk::Button* m_add_button;
	Gtk::Button* m_edit_button;
	Gtk::Button* m_delete_button;
	Gtk::Button* m_save_deck_button;
	Gtk::Button* m_close_button;
	Gtk::Button* m_more_button;
	Gtk::Button* m_card_up_button;
	Gtk::Button* m_card_down_button;
	Gtk::Button* m_add_card_to_cardbox;

	Gtk::Label*  m_label_count;

	VDeck& m_deck;
	int    m_row_idx;			// The row selected in the model
	bool   m_modified;			// Has Deck been modified to invalidate
                                // external iterators?
};

#endif /* DECK_VIEWER_H */

==> granule_1.2.1.2.orig.tar.gz: granule-1.2.1.2.orig/src/DeckView.h <==
// -*- c++ -*-
//------------------------------------------------------------------------------
// $Id: DeckView.h,v 1.23 2006/03/19 15:39:44 vlg Exp $
//------------------------------------------------------------------------------
//                            DeckView.h
//------------------------------------------------------------------------------
//  Copyright (c) 2004,2005 by Vladislav Grinchenko 
//
//  This program is free software; you can redistribute it and/or 
//  modify it under the terms of the GNU General Public License   
//  as published by the Free Software Foundation; either version  
//  2 of the License, or (at your option) any later version.      
//------------------------------------------------------------------------------
//
// Date   : Fri Feb  6 23:37:11 EST 2004
//
//------------------------------------------------------------------------------
#ifndef DECK_VIEWER_H
#define DECK_VIEWER_H

#ifdef HAVE_CONFIG_H
#    include "config.h"
#endif

#include <gtkmm/messagedialog.h>
#include <gtkmm/entry.h>
#include <gtkmm/label.h>
#include <gtkmm/frame.h>
#include <gtkmm/button.h>
#include <gtkmm/box.h>
#include <gtkmm/treeview.h>
#include <gtkmm/liststore.h>
#include <gtkmm/scrolledwindow.h>

#ifdef IS_HILDON
#include <hildon-widgetsmm/appview.h>
#endif

class VDeck;

#ifdef IS_HILDON 
class DeckView : public Hildon::AppView
#else
class DeckView : public Gtk::Dialog
#endif
{
public:
	DeckView (VDeck& deck_, int selected_row_);
	~DeckView ();

#ifdef IS_HILDON
	gint run ();
#endif

	/** Has the Deck been modified so that it might invalidate
		the iterators? Deleting a card and moving card(s) up/down
		might invalidated external iterators. 
		Editing/Saving, however, does not.
	*/
	bool is_modified () const { return m_modified; }

	/** User selected a row in the cards view
	 */
	void on_card_selected ();

	/** Called in response to pressing <Close> button
	 */
	void on_close_clicked ();

	/** Called when the user clicks on the column header to 
		sort the list of words.
	 */
	void on_column_sorted ();

	/** Sort Front column
	 */
	int on_sort_compare_front (const Gtk::TreeModel::iterator& a_, 
							   const Gtk::TreeModel::iterator& b_)
	{
		return (sort_compare_impl (a_, b_, 0));
	}

	/** Sort Back column
	 */
	int on_sort_compare_back (const Gtk::TreeModel::iterator& a_, 
							  const Gtk::TreeModel::iterator& b_)
	{
		return (sort_compare_impl (a_, b_, 1));
	}

	// -*- Sidebar action button callbacks -*-
	void on_add_clicked         ();
	void on_edit_clicked        ();
	void on_delete_clicked      ();
	void on_more_clicked        ();
	void on_card_up_clicked     ();
	void on_card_down_clicked   ();
	void on_add_card_to_cardbox ();
	void on_save_deck_clicked   ();

	void add_new_card (Card* card_);

private:
	/** Column sorting implementation
	 */
	int sort_compare_impl (const Gtk::TreeModel::iterator& a_, 
						   const Gtk::TreeModel::iterator& b_,
						   int column_);

	void set_cards_count ();
	void set_win_name ();

private:
	typedef Gtk::TreeModel::Children children_t;
	typedef children_t::iterator chiter_t;

	struct ModelColumns : public Gtk::TreeModelColumnRecord
	{
		Gtk::TreeModelColumn<Glib::ustring> m_front_row;
		Gtk::TreeModelColumn<Glib::ustring> m_back_row;
		Gtk::TreeModelColumn<VCard*>        m_card;    // Hidden Card reference.
		
		ModelColumns () 
			{ 
				add (m_front_row); add (m_back_row); add (m_card); 
			}
	};

	void autoscroll_up ();
	void autoscroll_down ();

	const ModelColumns   m_columns;
	Gtk::TreeView        m_tree_view;
	Gtk::ScrolledWindow* m_scrollwin;

	/// TreeModel
	Glib::RefPtr<Gtk::ListStore> m_list_store_ref; 

    /// Selection in current TreeView
	Glib::RefPtr<Gtk::TreeSelection> m_tree_sel_ref; 

	/** De-activate action buttons depending on the type 
	    of the underlying VDeck object.
	*/
	void set_sensitivity ();

#ifdef IS_HILDON
	Gtk::VBox* get_vbox () { return m_vbox; }
#endif

private:
	Gtk::Button* m_add_button;
	Gtk::Button* m_edit_button;
	Gtk::Button* m_delete_button;
	Gtk::Button* m_save_deck_button;
	Gtk::Button* m_close_button;
	Gtk::Button* m_more_button;
	Gtk::Button* m_card_up_button;
	Gtk::Button* m_card_down_button;
	Gtk::Button* m_add_card_to_cardbox;

	Gtk::Label*  m_label_count;

	VDeck& m_deck;
	int    m_row_idx;			// The row selected in the model
	bool   m_modified;			// Has Deck been modified to invalidate

#ifdef IS_HILDON
	Gtk::VBox*       m_vbox;
#endif

};

#endif /* DECK_VIEWER_H */
